@@ -177,6 +177,7 @@ public:
     virtual ~kernel_descriptor_t () = default;
 
     virtual amd_dbgapi_global_address_t entry_address () const = 0;
+    virtual bool is_at_kernel_entry (amd_dbgapi_global_address_t pc) const = 0;
 
     amd_dbgapi_global_address_t address () const { return m_address; }
     process_t &process () const { return m_process; }
@@ -203,7 +204,7 @@ public:
     virtual amd_dbgapi_wave_id_t id () const = 0;
     /* The 3-dimensional workgroup coordinates.  */
     virtual std::optional<std::array<uint32_t, 3>> group_ids () const = 0;
-    /* Return the record's postion in the workgroup.  */
+    /* Return the record's position in the workgroup.  */
     virtual std::optional<uint32_t> position_in_group () const = 0;
 
     /* Number of work-items in one wave.  */
@@ -219,7 +220,7 @@ public:
     virtual std::optional<amd_dbgapi_global_address_t>
     register_address (amdgpu_regnum_t regnum) const = 0;
 
-    /* Return true is a scratch slot is allocated for this record.  */
+    /* Return true if a scratch slot is allocated for this record.  */
     virtual bool is_scratch_enabled () const = 0;
 
     /* The shader engine ID this wave was created on.  */
@@ -287,10 +288,11 @@ public:
 
   virtual std::pair<amd_dbgapi_size_t /* offset  */,
                     amd_dbgapi_size_t /* size  */>
-  scratch_memory_region (uint32_t compute_tmpring_size_register,
-                         uint32_t shader_engine_count,
-                         uint32_t shader_engine_id,
-                         uint32_t scoreboard_id) const = 0;
+  scratch_memory_region (const agent_t &,
+                         uint32_t compute_tmpring_size_register,
+                         uint32_t xcc_id, uint32_t shader_engine_id,
+                         uint32_t scoreboard_id) const
+    = 0;
 
   virtual bool
   is_address_space_supported (const address_space_t &address_space) const = 0;
